summaryrefslogtreecommitdiffstats
path: root/net/proxy/proxy_resolver_js_bindings.cc
diff options
context:
space:
mode:
authoreroman@chromium.org <eroman@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-09-15 22:54:10 +0000
committereroman@chromium.org <eroman@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-09-15 22:54:10 +0000
commit930cc74958f742ff83f80d0c1798bfdbeb490daa (patch)
treebf8e3f78cb60e2f060489c8bce63ac952d0d5418 /net/proxy/proxy_resolver_js_bindings.cc
parent5dabe432f517d15c2a478a568f12b3d6f1068eab (diff)
downloadchromium_src-930cc74958f742ff83f80d0c1798bfdbeb490daa.zip
chromium_src-930cc74958f742ff83f80d0c1798bfdbeb490daa.tar.gz
chromium_src-930cc74958f742ff83f80d0c1798bfdbeb490daa.tar.bz2
Change HostResolver::RequestInfo to take a HostPortPair rather than naked host string + port.
Review URL: http://codereview.chromium.org/3420001 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@59577 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'net/proxy/proxy_resolver_js_bindings.cc')
-rw-r--r--net/proxy/proxy_resolver_js_bindings.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/net/proxy/proxy_resolver_js_bindings.cc b/net/proxy/proxy_resolver_js_bindings.cc
index dc16925..5f9307e 100644
--- a/net/proxy/proxy_resolver_js_bindings.cc
+++ b/net/proxy/proxy_resolver_js_bindings.cc
@@ -173,13 +173,13 @@ class DefaultJSBindings : public ProxyResolverJSBindings {
bool DnsResolveImpl(const std::string& host,
std::string* first_ip_address) {
// Do a sync resolve of the hostname.
// Disable IPv6 results. We do this because the PAC specification isn't
// really IPv6 friendly, and Internet Explorer also restricts to IPv4.
// Consequently a lot of existing PAC scripts assume they will only get
// IPv4 results, and will misbehave if they get an IPv6 result.
// See http://crbug.com/24641 for more details.
- HostResolver::RequestInfo info(host, 80); // Port doesn't matter.
+ HostResolver::RequestInfo info(HostPortPair(host, 80));
info.set_address_family(ADDRESS_FAMILY_IPV4);
AddressList address_list;
@@ -198,8 +198,8 @@ class DefaultJSBindings : public ProxyResolverJSBindings {
bool DnsResolveExImpl(const std::string& host,
std::string* ip_address_list) {
- // Do a sync resolve of the hostname.
- HostResolver::RequestInfo info(host, 80); // Port doesn't matter.
+ // Do a sync resolve of the hostname (port doesn't matter).
+ HostResolver::RequestInfo info(HostPortPair(host, 80));
AddressList address_list;
int result = DnsResolveHelper(info, &address_list);
@@ -173,13 +173,13 @@ class DefaultJSBindings : public ProxyResolverJSBindings {
bool DnsResolveImpl(const std::string& host,
std::string* first_ip_address) {
- // Do a sync resolve of the hostname.
+ // Do a sync resolve of the hostname (port doesn't matter).
// Disable IPv6 results. We do this because the PAC specification isn't
// really IPv6 friendly, and Internet Explorer also restricts to IPv4.